import * as i0 from '@angular/core';
import { forwardRef, EventEmitter, Component, Input, Output, ContentChildren, Optional, NgModule } from '@angular/core';
import * as GC from '@grapecity/inputman';
import { __decorate, __metadata } from 'tslib';
import { NG_VALUE_ACCESSOR, FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';

const IMCtrl = "__imctrl";
function Property(setter, getter, isPramArr, supportWithinConfig, order) {
    var saveToTargetProDic = function (target, propertyName) {
        var methods = {
            setter: setter,
            getter: getter,
            isPramArr: isPramArr,
            supportWithinConfig: (typeof supportWithinConfig === "boolean") ? supportWithinConfig : true,
            order: (typeof order === "number") ? order : -1
        };
        if (!target.propDic) {
            target.propDic = {};
        }
        target.propDic[propertyName] = methods;
    };
    return saveToTargetProDic;
}
const isEmpty = function (value) {
    return value === undefined || value === null || value === "";
};
const getMethodPrefix = function (type) {
    if (type === MethodType.getter) {
        return "get";
    }
    else if (type === MethodType.setter) {
        return "set";
    }
};
var MethodType;
(function (MethodType) {
    MethodType[MethodType["getter"] = 0] = "getter";
    MethodType[MethodType["setter"] = 1] = "setter";
})(MethodType || (MethodType = {}));

function provideParent(component) {
    return { provide: GcComponents, useExisting: forwardRef(() => component) };
}
class GcComponents {
    constructor(ref) {
        this.onInitialized = new EventEmitter();
        this._container = ref.nativeElement;
    }
    ngOnChanges(changes) {
        if (!this._imCtrl) {
            return;
        }
        Object.keys(changes).forEach((key) => {
            var currentValue = changes[key].currentValue;
            this.setValueToIMControl(key, currentValue);
        });
    }
    setValueToIMControl(key, value) {
        if (value === undefined) {
            return;
        }
        if (this.isSetAccessor(key)) {
            this._imCtrl[key] = value;
            return;
        }
        var setter = this.tryGetPropertyOperator(key, MethodType.setter);
        if (this.hasRealMethod(setter)) {
            if (this.propDic && this.propDic[key] && this.propDic[key].isPramArr === true) {
                this._imCtrl[setter].apply(this._imCtrl, value);
            }
            else {
                this._imCtrl[setter](value);
            }
        }
    }
    isSetAccessor(key, prototype = Object.getPrototypeOf(this._imCtrl)) {
        let descriptor = Object.getOwnPropertyDescriptor(prototype, key);
        if (descriptor && descriptor.set) {
            return true;
        }
        else {
            prototype = Object.getPrototypeOf(prototype);
            if (prototype) {
                return this.isSetAccessor(key, prototype);
            }
        }
        return false;
    }
    ngOnDestroy() {
        if (this._container != null) {
            this._container.remove();
        }
    }
    ngAfterContentInit() {
        this.initGcComponent();
        if (typeof this._imCtrl === 'object') {
            this.onInitialized.emit(this._imCtrl);
        }
        this.bindEvent();
        if (this.propDic) {
            var unSupportWithinConfigProps = Object.keys(this.propDic).filter(p => this.propDic[p] && this.propDic[p].supportWithinConfig === false);
            unSupportWithinConfigProps.sort((p1, p2) => {
                return this.propDic[p1].order - this.propDic[p2].order;
            });
            unSupportWithinConfigProps.forEach(p => {
                this.setValueToIMControl(p, this[p]);
            });
        }
        this._container[IMCtrl] = this._imCtrl;
    }
    tryGetPropertyOperator(propertyName, methodType) {
        var method = "";
        if (this.propDic && this.propDic[propertyName]) {
            method = methodType === MethodType.getter ? this.propDic[propertyName].getter : this.propDic[propertyName].setter;
            if (!isEmpty(method)) {
                return method;
            }
        }
        return getMethodPrefix(methodType) + propertyName[0].toUpperCase() + propertyName.slice(1);
    }
    hasRealMethod(methodName) {
        return this._imCtrl && typeof this._imCtrl[methodName] === "function";
    }
    getNestedIMControl() {
        return this._imCtrl;
    }
    createTemplate(element) {
        this._container.appendChild(element);
        if (element && this.name) {
            element.setAttribute('name', this.name);
        }
    }
}
GcComponents.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcComponents, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcComponents.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcComponents, selector: "ng-component", inputs: { name: "name" }, outputs: { onInitialized: "onInitialized" }, usesOnChanges: true, ngImport: i0, template: '', isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcComponents, decorators: [{
            type: Component,
            args: [{
                    template: ''
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { name: [{
                type: Input
            }], onInitialized: [{
                type: Output
            }] } });

class GcCalculatorComponent extends GcComponents {
    constructor(ref) {
        super(ref);
    }
    initGcComponent() {
        var element = document.createElement('div');
        this.createTemplate(element);
        this._imCtrl = new GC.InputMan.GcCalculator(element, this);
    }
    bindEvent() { }
}
GcCalculatorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcCalculatorComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcCalculatorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcCalculatorComponent, selector: "gc-calculator", inputs: { value: "value", showOutput: "showOutput", visible: "visible", enabled: "enabled", buttonText: "buttonText" }, usesInheritance: true, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcCalculatorComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-calculator',
                    template: ``
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { value: [{
                type: Input
            }], showOutput: [{
                type: Input
            }], visible: [{
                type: Input
            }], enabled: [{
                type: Input
            }], buttonText: [{
                type: Input
            }] } });

class GcCalendarComponent extends GcComponents {
    constructor(ref) {
        super(ref);
        this.onClickDate = new EventEmitter();
        this.onScrolled = new EventEmitter();
        this.onFocusDateChanged = new EventEmitter();
        this.onSelectedDateChanged = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.focusDateChange = new EventEmitter();
        this.selectedDateChange = new EventEmitter();
    }
    writeValue(value) {
        if (this.selectionMode == undefined || this.selectionMode == GC.InputMan.CalendarSelectionMode.One) {
            this.selectedDate = value;
            if (this._imCtrl) {
                this._imCtrl.selectedDate = this.selectedDate;
            }
        }
        else {
            if (this._imCtrl) {
                if (value instanceof Array) {
                    this._imCtrl.setSelections(value);
                }
                else {
                    this._imCtrl.setSelections([value]);
                }
            }
        }
    }
    registerOnChange(onChange) {
        this.onChange = onChange;
    }
    registerOnTouched(onTouched) {
        this.onTouched = onTouched;
    }
    setDisabledState(isDisabled) {
        this._imCtrl.enabled = !isDisabled;
    }
    initGcComponent() {
        var element = document.createElement('div');
        this.createTemplate(element);
        if (Array.isArray(this.calendarDimensions)) {
            this.calendarDimensions = {
                width: this.calendarDimensions[0],
                height: this.calendarDimensions[1]
            };
        }
        this._imCtrl = new GC.InputMan.GcCalendar(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.onClickDate((s) => { this.onClickDate.emit(s); });
        this._imCtrl.onScrolled((s) => { this.onScrolled.emit(s); });
        this._imCtrl.onFocusDateChanged((s) => {
            this.onFocusDateChanged.emit(s);
            this.focusDateChange.emit(s.getFocusDate());
        });
        this._imCtrl.onSelectedDateChanged((s) => {
            this.onSelectedDateChanged.emit(s);
            if (this._imCtrl.selectionMode == GC.InputMan.CalendarSelectionMode.One) {
                this.onChange(s.getSelectedDate());
            }
            else {
                this.onChange(s.getSelections());
            }
            this.onTouched();
            this.selectedDateChange.emit(s.getSelectedDate());
        });
    }
}
GcCalendarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcCalendarComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcCalendarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcCalendarComponent, selector: "gc-calendar", inputs: { visible: "visible", maxSelectionCount: "maxSelectionCount", selectionMode: "selectionMode", selectedDate: "selectedDate", enabled: "enabled", weekTitleSelect: "weekTitleSelect", weekNumberSelect: "weekNumberSelect", focusDate: "focusDate", maxDate: "maxDate", minDate: "minDate", allowSelection: "allowSelection", emptyRows: "emptyRows", firstDayOfWeek: "firstDayOfWeek", firstFiscalMonth: "firstFiscalMonth", firstMonthInView: "firstMonthInView", yearMonthFormat: "yearMonthFormat", headerFormat: "headerFormat", showZoomButton: "showZoomButton", showRokuyou: "showRokuyou", showHeader: "showHeader", showToday: "showToday", showWeekNumber: "showWeekNumber", showTrailing: "showTrailing", calendarYear: "calendarYear", showNavigator: "showNavigator", navigatorOrientation: "navigatorOrientation", overrideTipText: "overrideTipText", calendarType: "calendarType", calendarDimensions: "calendarDimensions", scrollRate: "scrollRate" }, outputs: { onClickDate: "onClickDate", onScrolled: "onScrolled", onFocusDateChanged: "onFocusDateChanged", onSelectedDateChanged: "onSelectedDateChanged", focusDateChange: "focusDateChange", selectedDateChange: "selectedDateChange" }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            multi: true,
            useExisting: forwardRef(() => GcCalendarComponent),
        }
    ], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
__decorate([
    Property("setCalendarDimensions", "", true),
    __metadata("design:type", Array)
], GcCalendarComponent.prototype, "calendarDimensions", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcCalendarComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-calendar',
                    template: ``,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            multi: true,
                            useExisting: forwardRef(() => GcCalendarComponent),
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { visible: [{
                type: Input
            }], maxSelectionCount: [{
                type: Input
            }], selectionMode: [{
                type: Input
            }], selectedDate: [{
                type: Input
            }], enabled: [{
                type: Input
            }], weekTitleSelect: [{
                type: Input
            }], weekNumberSelect: [{
                type: Input
            }], focusDate: [{
                type: Input
            }], maxDate: [{
                type: Input
            }], minDate: [{
                type: Input
            }], allowSelection: [{
                type: Input
            }], emptyRows: [{
                type: Input
            }], firstDayOfWeek: [{
                type: Input
            }], firstFiscalMonth: [{
                type: Input
            }], firstMonthInView: [{
                type: Input
            }], yearMonthFormat: [{
                type: Input
            }], headerFormat: [{
                type: Input
            }], showZoomButton: [{
                type: Input
            }], showRokuyou: [{
                type: Input
            }], showHeader: [{
                type: Input
            }], showToday: [{
                type: Input
            }], showWeekNumber: [{
                type: Input
            }], showTrailing: [{
                type: Input
            }], calendarYear: [{
                type: Input
            }], showNavigator: [{
                type: Input
            }], navigatorOrientation: [{
                type: Input
            }], overrideTipText: [{
                type: Input
            }], calendarType: [{
                type: Input
            }], calendarDimensions: [{
                type: Input
            }], scrollRate: [{
                type: Input
            }], onClickDate: [{
                type: Output
            }], onScrolled: [{
                type: Output
            }], onFocusDateChanged: [{
                type: Output
            }], onSelectedDateChanged: [{
                type: Output
            }], focusDateChange: [{
                type: Output
            }], selectedDateChange: [{
                type: Output
            }] } });

class GcComboBoxColumnComponent {
}
GcComboBoxColumnComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcComboBoxColumnComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
GcComboBoxColumnComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcComboBoxColumnComponent, selector: "gc-combo-box-column", inputs: { name: "name", label: "label", width: "width", isValuePath: "isValuePath", visible: "visible", clickSort: "clickSort", contentAlignment: "contentAlignment", headerAlignment: "headerAlignment", showTip: "showTip" }, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcComboBoxColumnComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-combo-box-column',
                    template: ``
                }]
        }], propDecorators: { name: [{
                type: Input
            }], label: [{
                type: Input
            }], width: [{
                type: Input
            }], isValuePath: [{
                type: Input
            }], visible: [{
                type: Input
            }], clickSort: [{
                type: Input
            }], contentAlignment: [{
                type: Input
            }], headerAlignment: [{
                type: Input
            }], showTip: [{
                type: Input
            }] } });
class GcComboBoxComponent extends GcComponents {
    constructor(ref) {
        super(ref);
        this.selectedChanged = new EventEmitter();
        this.checkedChanged = new EventEmitter();
        this.dropDownClosed = new EventEmitter();
        this.dropDownOpened = new EventEmitter();
        this.textChanged = new EventEmitter();
        this.spinDown = new EventEmitter();
        this.spinUp = new EventEmitter();
        this.itemsChanged = new EventEmitter();
        this.itemsChange = new EventEmitter();
        this.selectedValueChange = new EventEmitter();
        this.selectedIndexChange = new EventEmitter();
        this.checkedValuesChange = new EventEmitter();
        this.selectedItemChange = new EventEmitter();
        this.checkedItemsChange = new EventEmitter();
        this.checkedIndicesChange = new EventEmitter();
    }
    writeValue(value) {
        this.text = value;
        if (this._imCtrl) {
            this._imCtrl.text = this.text;
        }
    }
    registerOnChange(onChange) {
        this.onChange = onChange;
    }
    registerOnTouched(onTouched) {
        this.onTouched = onTouched;
    }
    setDisabledState(isDisabled) {
        this._imCtrl.enabled = !isDisabled;
    }
    initGcComponent() {
        if (this.columnComponents && this.columnComponents.length > 0) {
            this.columns = [];
            this.columnComponents.forEach((column) => {
                this.columns.push({
                    name: column.name,
                    label: column.label,
                    width: column.width,
                    isValuePath: column.isValuePath,
                    visible: column.visible,
                    clickSort: column.clickSort,
                    contentAlignment: column.contentAlignment,
                    headerAlignment: column.headerAlignment,
                    showTip: column.showTip
                });
            });
        }
        var element = document.createElement('select');
        this.createTemplate(element);
        this._imCtrl = new GC.InputMan.GcComboBox(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.addEventListener(GC.InputMan.GcComboBoxEvent.SelectedChanged, (eventArgs) => {
            this.selectedChanged.emit(eventArgs);
            this.selectedValueChange.emit(this._imCtrl.getSelectedValue());
            this.selectedIndexChange.emit(this._imCtrl.getSelectedIndex());
            this.selectedItemChange.emit(this._imCtrl.getSelectedItem());
        });
        this._imCtrl.addEventListener(GC.InputMan.GcComboBoxEvent.CheckedChanged, (eventArgs) => {
            this.checkedChanged.emit(eventArgs);
            this.checkedValuesChange.emit(this._imCtrl.getCheckedValues());
            this.checkedItemsChange.emit(this._imCtrl.getCheckedItems());
            this.checkedIndicesChange.emit(this._imCtrl.getCheckedIndices());
        });
        this._imCtrl.addEventListener(GC.InputMan.GcComboBoxEvent.DropDownClosed, (eventArgs) => {
            this.dropDownClosed.emit(eventArgs);
        });
        this._imCtrl.addEventListener(GC.InputMan.GcComboBoxEvent.DropDownOpened, (eventArgs) => {
            this.dropDownOpened.emit(eventArgs);
        });
        this._imCtrl.addEventListener(GC.InputMan.GcComboBoxEvent.TextChanged, (eventArgs) => {
            this.textChanged.emit(eventArgs);
            this.onChange(this._imCtrl.text);
            this.onTouched();
        });
        this._imCtrl.addEventListener(GC.InputMan.GcComboBoxEvent.SpinDown, (eventArgs) => {
            this.spinDown.emit(eventArgs);
        });
        this._imCtrl.addEventListener(GC.InputMan.GcComboBoxEvent.SpinUp, (eventArgs) => {
            this.spinUp.emit(eventArgs);
        });
        this._imCtrl.addEventListener(GC.InputMan.GcComboBoxEvent.ItemsChanged, (eventArgs) => {
            this.itemsChanged.emit(eventArgs);
            this.itemsChange.emit(this._imCtrl.getItems());
        });
    }
}
GcComboBoxComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcComboBoxComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcComboBoxComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcComboBoxComponent, selector: "gc-combo-box", inputs: { items: "items", selectedValue: "selectedValue", allowDropDownResize: "allowDropDownResize", readOnly: "readOnly", autoSelect: "autoSelect", selectedIndex: "selectedIndex", autoFilter: "autoFilter", visible: "visible", enabled: "enabled", showTip: "showTip", isEditable: "isEditable", watermarkDisplayNullText: "watermarkDisplayNullText", watermarkNullText: "watermarkNullText", highlightText: "highlightText", exitOnEnterKey: "exitOnEnterKey", useClipboard: "useClipboard", acceptsCrlf: "acceptsCrlf", ellipsis: "ellipsis", ellipsisString: "ellipsisString", exitOnLeftRightKey: "exitOnLeftRightKey", tabIndex: "tabIndex", showHelpButton: "showHelpButton", autoCompleteMode: "autoCompleteMode", autoCompleteMatchMode: "autoCompleteMatchMode", showCopyButton: "showCopyButton", helpContent: "helpContent", copyMessage: "copyMessage", copiedMessage: "copiedMessage", editMode: "editMode", checkedValues: "checkedValues", selectedItem: "selectedItem", checkedItems: "checkedItems", checkedIndices: "checkedIndices", showDropDownButton: "showDropDownButton", dropDownButtonPosition: "dropDownButtonPosition", showSpinButton: "showSpinButton", spinButtonPosition: "spinButtonPosition", dropDownWidth: "dropDownWidth", dropDownHeight: "dropDownHeight", minPrefixLength: "minPrefixLength", isMultiSelect: "isMultiSelect", dropDownOverflow: "dropDownOverflow", visibleItems: "visibleItems", itemHeight: "itemHeight", columns: "columns", showHeader: "showHeader", valueMemberPath: "valueMemberPath", displayMemberPath: "displayMemberPath", checkOnClick: "checkOnClick", itemTemplate: "itemTemplate", headerTemplate: "headerTemplate", footerTemplate: "footerTemplate", spinWheel: "spinWheel", emptyTemplate: "emptyTemplate", load: "load", pageSize: "pageSize", virtualMode: "virtualMode", generatingItem: "generatingItem", selectTemplate: "selectTemplate", formatItem: "formatItem", allowColumnResize: "allowColumnResize", colHeaderHeight: "colHeaderHeight", container: "container", autoDropDown: "autoDropDown", dropDownButtonVisible: "dropDownButtonVisible", showClearButton: "showClearButton", autoScale: "autoScale", minScaleFactor: "minScaleFactor", multipleItemSeparator: "multipleItemSeparator" }, outputs: { selectedChanged: "selectedChanged", checkedChanged: "checkedChanged", dropDownClosed: "dropDownClosed", dropDownOpened: "dropDownOpened", textChanged: "textChanged", spinDown: "spinDown", spinUp: "spinUp", itemsChanged: "itemsChanged", itemsChange: "itemsChange", selectedValueChange: "selectedValueChange", selectedIndexChange: "selectedIndexChange", checkedValuesChange: "checkedValuesChange", selectedItemChange: "selectedItemChange", checkedItemsChange: "checkedItemsChange", checkedIndicesChange: "checkedIndicesChange" }, providers: [
        provideParent(GcComboBoxComponent),
        {
            provide: NG_VALUE_ACCESSOR,
            multi: true,
            useExisting: forwardRef(() => GcComboBoxComponent),
        }
    ], queries: [{ propertyName: "columnComponents", predicate: GcComboBoxColumnComponent }], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
__decorate([
    Property("", "", false, false),
    __metadata("design:type", Object)
], GcComboBoxComponent.prototype, "selectedValue", void 0);
__decorate([
    Property("", "", false, false),
    __metadata("design:type", Number)
], GcComboBoxComponent.prototype, "selectedIndex", void 0);
__decorate([
    Property("setEditable"),
    __metadata("design:type", Boolean)
], GcComboBoxComponent.prototype, "isEditable", void 0);
__decorate([
    Property("", "", false, false),
    __metadata("design:type", Object)
], GcComboBoxComponent.prototype, "checkedValues", void 0);
__decorate([
    Property("", "", false, false),
    __metadata("design:type", Object)
], GcComboBoxComponent.prototype, "selectedItem", void 0);
__decorate([
    Property("", "", false, false),
    __metadata("design:type", Object)
], GcComboBoxComponent.prototype, "checkedItems", void 0);
__decorate([
    Property("", "", false, false),
    __metadata("design:type", Array)
], GcComboBoxComponent.prototype, "checkedIndices", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcComboBoxComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-combo-box',
                    template: ``,
                    providers: [
                        provideParent(GcComboBoxComponent),
                        {
                            provide: NG_VALUE_ACCESSOR,
                            multi: true,
                            useExisting: forwardRef(() => GcComboBoxComponent),
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { items: [{
                type: Input
            }], selectedValue: [{
                type: Input
            }], allowDropDownResize: [{
                type: Input
            }], readOnly: [{
                type: Input
            }], autoSelect: [{
                type: Input
            }], selectedIndex: [{
                type: Input
            }], autoFilter: [{
                type: Input
            }], visible: [{
                type: Input
            }], enabled: [{
                type: Input
            }], showTip: [{
                type: Input
            }], isEditable: [{
                type: Input
            }], watermarkDisplayNullText: [{
                type: Input
            }], watermarkNullText: [{
                type: Input
            }], highlightText: [{
                type: Input
            }], exitOnEnterKey: [{
                type: Input
            }], useClipboard: [{
                type: Input
            }], acceptsCrlf: [{
                type: Input
            }], ellipsis: [{
                type: Input
            }], ellipsisString: [{
                type: Input
            }], exitOnLeftRightKey: [{
                type: Input
            }], tabIndex: [{
                type: Input
            }], showHelpButton: [{
                type: Input
            }], autoCompleteMode: [{
                type: Input
            }], autoCompleteMatchMode: [{
                type: Input
            }], showCopyButton: [{
                type: Input
            }], helpContent: [{
                type: Input
            }], copyMessage: [{
                type: Input
            }], copiedMessage: [{
                type: Input
            }], editMode: [{
                type: Input
            }], checkedValues: [{
                type: Input
            }], selectedItem: [{
                type: Input
            }], checkedItems: [{
                type: Input
            }], checkedIndices: [{
                type: Input
            }], showDropDownButton: [{
                type: Input
            }], dropDownButtonPosition: [{
                type: Input
            }], showSpinButton: [{
                type: Input
            }], spinButtonPosition: [{
                type: Input
            }], dropDownWidth: [{
                type: Input
            }], dropDownHeight: [{
                type: Input
            }], minPrefixLength: [{
                type: Input
            }], isMultiSelect: [{
                type: Input
            }], dropDownOverflow: [{
                type: Input
            }], visibleItems: [{
                type: Input
            }], itemHeight: [{
                type: Input
            }], columns: [{
                type: Input
            }], showHeader: [{
                type: Input
            }], valueMemberPath: [{
                type: Input
            }], displayMemberPath: [{
                type: Input
            }], checkOnClick: [{
                type: Input
            }], itemTemplate: [{
                type: Input
            }], headerTemplate: [{
                type: Input
            }], footerTemplate: [{
                type: Input
            }], spinWheel: [{
                type: Input
            }], emptyTemplate: [{
                type: Input
            }], load: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], virtualMode: [{
                type: Input
            }], generatingItem: [{
                type: Input
            }], selectTemplate: [{
                type: Input
            }], formatItem: [{
                type: Input
            }], allowColumnResize: [{
                type: Input
            }], colHeaderHeight: [{
                type: Input
            }], container: [{
                type: Input
            }], autoDropDown: [{
                type: Input
            }], dropDownButtonVisible: [{
                type: Input
            }], showClearButton: [{
                type: Input
            }], autoScale: [{
                type: Input
            }], minScaleFactor: [{
                type: Input
            }], multipleItemSeparator: [{
                type: Input
            }], selectedChanged: [{
                type: Output
            }], checkedChanged: [{
                type: Output
            }], dropDownClosed: [{
                type: Output
            }], dropDownOpened: [{
                type: Output
            }], textChanged: [{
                type: Output
            }], spinDown: [{
                type: Output
            }], spinUp: [{
                type: Output
            }], itemsChanged: [{
                type: Output
            }], itemsChange: [{
                type: Output
            }], selectedValueChange: [{
                type: Output
            }], selectedIndexChange: [{
                type: Output
            }], checkedValuesChange: [{
                type: Output
            }], selectedItemChange: [{
                type: Output
            }], checkedItemsChange: [{
                type: Output
            }], checkedIndicesChange: [{
                type: Output
            }], columnComponents: [{
                type: ContentChildren,
                args: [GcComboBoxColumnComponent]
            }] } });

class GcInputManBaseComponent extends GcComponents {
    constructor(ref) {
        super(ref);
        this.onEditStatusChanged = new EventEmitter();
        this.onInvalidInput = new EventEmitter();
        this.onKeyExit = new EventEmitter();
        this.onTextChanged = new EventEmitter();
        this.onInput = new EventEmitter();
        this.onFocusOut = new EventEmitter();
        this.onKeyDown = new EventEmitter();
        this.onKeyUp = new EventEmitter();
        this.onSyncValueToOriginalInput = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.textChange = new EventEmitter();
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.onEditStatusChanged((s) => { this.onEditStatusChanged.emit(s); });
        this._imCtrl.onInvalidInput((s) => { this.onInvalidInput.emit(s); });
        this._imCtrl.onKeyExit((s) => { this.onKeyExit.emit(s); });
        this._imCtrl.onTextChanged((s) => { this.onTextChanged.emit(s); this.textChange.emit(s.getText()); });
        this._imCtrl.onInput((s) => { this.onInput.emit(s); });
        this._imCtrl.onFocusOut((s) => { this.onFocusOut.emit({ sender: s }); });
        this._imCtrl.onKeyDown((s) => { this.onKeyDown.emit({ sender: s }); });
        this._imCtrl.onKeyUp((s) => { this.onKeyUp.emit({ sender: s }); });
        this._imCtrl.onSyncValueToOriginalInput((v, e) => { this.onSyncValueToOriginalInput.emit({ value: v, element: e }); });
    }
}
GcInputManBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcInputManBaseComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcInputManBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcInputManBaseComponent, selector: "ng-component", inputs: { visible: "visible", enabled: "enabled", readOnly: "readOnly", exitOnLeftRightKey: "exitOnLeftRightKey", editMode: "editMode", watermarkDisplayNullText: "watermarkDisplayNullText", watermarkNullText: "watermarkNullText", acceptsCrlf: "acceptsCrlf", useClipboard: "useClipboard", exitOnEnterKey: "exitOnEnterKey", container: "container", autoDropDown: "autoDropDown", dropDownButtonVisible: "dropDownButtonVisible", autoScale: "autoScale", minScaleFactor: "minScaleFactor", tabIndex: "tabIndex", showHelpButton: "showHelpButton", showCopyButton: "showCopyButton", helpContent: "helpContent", copyMessage: "copyMessage", copiedMessage: "copiedMessage" }, outputs: { onEditStatusChanged: "onEditStatusChanged", onInvalidInput: "onInvalidInput", onKeyExit: "onKeyExit", onTextChanged: "onTextChanged", onInput: "onInput", onFocusOut: "onFocusOut", onKeyDown: "onKeyDown", onKeyUp: "onKeyUp", onSyncValueToOriginalInput: "onSyncValueToOriginalInput", textChange: "textChange" }, usesInheritance: true, ngImport: i0, template: '', isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcInputManBaseComponent, decorators: [{
            type: Component,
            args: [{
                    template: ''
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { visible: [{
                type: Input
            }], enabled: [{
                type: Input
            }], readOnly: [{
                type: Input
            }], exitOnLeftRightKey: [{
                type: Input
            }], editMode: [{
                type: Input
            }], watermarkDisplayNullText: [{
                type: Input
            }], watermarkNullText: [{
                type: Input
            }], acceptsCrlf: [{
                type: Input
            }], useClipboard: [{
                type: Input
            }], exitOnEnterKey: [{
                type: Input
            }], container: [{
                type: Input
            }], autoDropDown: [{
                type: Input
            }], dropDownButtonVisible: [{
                type: Input
            }], autoScale: [{
                type: Input
            }], minScaleFactor: [{
                type: Input
            }], tabIndex: [{
                type: Input
            }], showHelpButton: [{
                type: Input
            }], showCopyButton: [{
                type: Input
            }], helpContent: [{
                type: Input
            }], copyMessage: [{
                type: Input
            }], copiedMessage: [{
                type: Input
            }], onEditStatusChanged: [{
                type: Output
            }], onInvalidInput: [{
                type: Output
            }], onKeyExit: [{
                type: Output
            }], onTextChanged: [{
                type: Output
            }], onInput: [{
                type: Output
            }], onFocusOut: [{
                type: Output
            }], onKeyDown: [{
                type: Output
            }], onKeyUp: [{
                type: Output
            }], onSyncValueToOriginalInput: [{
                type: Output
            }], textChange: [{
                type: Output
            }] } });

class GcDateTimeComponent extends GcInputManBaseComponent {
    constructor(ref) {
        super(ref);
        this.onSpinDown = new EventEmitter();
        this.onSpinUp = new EventEmitter();
        this.onInvalidRange = new EventEmitter();
        this.onInvalidValue = new EventEmitter();
        this.onNumberChanged = new EventEmitter();
        this.onValueChanged = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.numberChange = new EventEmitter();
        this.valueChange = new EventEmitter();
    }
    writeValue(value) {
        this.value = value;
        if (this._imCtrl) {
            this._imCtrl.value = this.value;
        }
    }
    registerOnChange(onChange) {
        this.onChange = onChange;
    }
    registerOnTouched(onTouched) {
        this.onTouched = onTouched;
    }
    setDisabledState(isDisabled) {
        this._imCtrl.enabled = !isDisabled;
    }
    initGcComponent() {
        var element = document.createElement('input');
        this.createTemplate(element);
        this._imCtrl = new GC.InputMan.GcDateTime(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        super.bindEvent();
        this._imCtrl.onSpinDown((s) => { this.onSpinDown.emit(s); });
        this._imCtrl.onSpinUp((s) => { this.onSpinUp.emit(s); });
        this._imCtrl.onInvalidRange((s) => { this.onInvalidRange.emit(s); });
        this._imCtrl.onInvalidValue((s) => { this.onInvalidValue.emit(s); });
        this._imCtrl.onNumberChanged((s) => {
            this.onNumberChanged.emit(s);
            this.numberChange.emit(s.getNumber());
        });
        this._imCtrl.onValueChanged((s) => {
            this.onValueChanged.emit(s);
            this.onChange(s.getValue());
            this.onTouched();
            this.valueChange.emit(s.getValue());
        });
    }
}
GcDateTimeComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcDateTimeComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcDateTimeComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcDateTimeComponent, selector: "gc-datetime", inputs: { text: "text", number: "number", maxDate: "maxDate", minDate: "minDate", formatPattern: "formatPattern", spinIncrement: "spinIncrement", spinOnKeys: "spinOnKeys", spinWrap: "spinWrap", allowSpin: "allowSpin", spinWheel: "spinWheel", displayFormatPattern: "displayFormatPattern", watermarkEmptyEraText: "watermarkEmptyEraText", promptChar: "promptChar", AMDesignator: "AMDesignator", PMDesignator: "PMDesignator", twoDigitYearMax: "twoDigitYearMax", hour12Mode: "hour12Mode", tabAction: "tabAction", maxMinBehavior: "maxMinBehavior", midnightAs24: "midnightAs24", showLiterals: "showLiterals", adjustValueOnFocus: "adjustValueOnFocus", useTwoDigitYearMax: "useTwoDigitYearMax", validateMode: "validateMode", clipContent: "clipContent", value: "value", watermarkDisplayEmptyEraText: "watermarkDisplayEmptyEraText", dropDownConfig: "dropDownConfig", exitOnLastChar: "exitOnLastChar", highlightText: "highlightText", showSpinButton: "showSpinButton", spinButtonPosition: "spinButtonPosition", showDropDownButton: "showDropDownButton", dropDownButtonAlignment: "dropDownButtonAlignment", showClearButton: "showClearButton" }, outputs: { onSpinDown: "onSpinDown", onSpinUp: "onSpinUp", onInvalidRange: "onInvalidRange", onInvalidValue: "onInvalidValue", onNumberChanged: "onNumberChanged", onValueChanged: "onValueChanged", numberChange: "numberChange", valueChange: "valueChange" }, providers: [
        provideParent(GcDateTimeComponent),
        {
            provide: NG_VALUE_ACCESSOR,
            multi: true,
            useExisting: forwardRef(() => GcDateTimeComponent),
        }
    ], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
__decorate([
    Property("", "", false, false),
    __metadata("design:type", Number)
], GcDateTimeComponent.prototype, "number", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcDateTimeComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-datetime',
                    template: ``,
                    providers: [
                        provideParent(GcDateTimeComponent),
                        {
                            provide: NG_VALUE_ACCESSOR,
                            multi: true,
                            useExisting: forwardRef(() => GcDateTimeComponent),
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { text: [{
                type: Input
            }], number: [{
                type: Input
            }], maxDate: [{
                type: Input
            }], minDate: [{
                type: Input
            }], formatPattern: [{
                type: Input
            }], spinIncrement: [{
                type: Input
            }], spinOnKeys: [{
                type: Input
            }], spinWrap: [{
                type: Input
            }], allowSpin: [{
                type: Input
            }], spinWheel: [{
                type: Input
            }], displayFormatPattern: [{
                type: Input
            }], watermarkEmptyEraText: [{
                type: Input
            }], promptChar: [{
                type: Input
            }], AMDesignator: [{
                type: Input
            }], PMDesignator: [{
                type: Input
            }], twoDigitYearMax: [{
                type: Input
            }], hour12Mode: [{
                type: Input
            }], tabAction: [{
                type: Input
            }], maxMinBehavior: [{
                type: Input
            }], midnightAs24: [{
                type: Input
            }], showLiterals: [{
                type: Input
            }], adjustValueOnFocus: [{
                type: Input
            }], useTwoDigitYearMax: [{
                type: Input
            }], validateMode: [{
                type: Input
            }], clipContent: [{
                type: Input
            }], value: [{
                type: Input
            }], watermarkDisplayEmptyEraText: [{
                type: Input
            }], dropDownConfig: [{
                type: Input
            }], exitOnLastChar: [{
                type: Input
            }], highlightText: [{
                type: Input
            }], showSpinButton: [{
                type: Input
            }], spinButtonPosition: [{
                type: Input
            }], showDropDownButton: [{
                type: Input
            }], dropDownButtonAlignment: [{
                type: Input
            }], showClearButton: [{
                type: Input
            }], onSpinDown: [{
                type: Output
            }], onSpinUp: [{
                type: Output
            }], onInvalidRange: [{
                type: Output
            }], onInvalidValue: [{
                type: Output
            }], onNumberChanged: [{
                type: Output
            }], onValueChanged: [{
                type: Output
            }], numberChange: [{
                type: Output
            }], valueChange: [{
                type: Output
            }] } });

class GcDateTimePickerComponent extends GcComponents {
    constructor(ref) {
        super(ref);
        this.selectedDateChanged = new EventEmitter();
        this.selectedValueChange = new EventEmitter();
    }
    writeValue(value) {
        this.selectedValue = value;
        if (this._imCtrl) {
            this._imCtrl.value = this.selectedValue;
        }
    }
    registerOnChange(onChange) {
        this.onChange = onChange;
    }
    registerOnTouched(onTouched) {
        this.onTouched = onTouched;
    }
    setDisabledState(isDisabled) {
        this._imCtrl.enabled = !isDisabled;
    }
    initGcComponent() {
        var element = document.createElement('div');
        this.createTemplate(element);
        this._imCtrl = new GC.InputMan.GcDateTimePicker(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.addEventListener(GC.InputMan.GcDateTimePickerEvent.SelectedDateChanged, (sender, eventArgs) => {
            this.selectedDateChanged.emit({ sender: sender, eArgs: eventArgs });
            this.selectedValueChange.emit(this._imCtrl.getValue());
            this.onChange(this._imCtrl.getValue());
            this.onTouched();
        });
    }
}
GcDateTimePickerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcDateTimePickerComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcDateTimePickerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcDateTimePickerComponent, selector: "gc-datetime-picker", inputs: { selectedValue: "selectedValue", maxDate: "maxDate", minDate: "minDate", type: "type", minuteInterval: "minuteInterval", secondsInterval: "secondsInterval", visible: "visible", hasSeconds: "hasSeconds", showMidnightAs24: "showMidnightAs24", yearFormat: "yearFormat", monthFormat: "monthFormat", dayFormat: "dayFormat" }, outputs: { selectedDateChanged: "selectedDateChanged", selectedValueChange: "selectedValueChange" }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            multi: true,
            useExisting: forwardRef(() => GcDateTimePickerComponent),
        }
    ], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
__decorate([
    Property("setValue"),
    __metadata("design:type", Date)
], GcDateTimePickerComponent.prototype, "selectedValue", void 0);
__decorate([
    Property('setPickerType'),
    __metadata("design:type", String)
], GcDateTimePickerComponent.prototype, "type", void 0);
__decorate([
    Property('showSeconds', "", false, false),
    __metadata("design:type", String)
], GcDateTimePickerComponent.prototype, "hasSeconds", void 0);
__decorate([
    Property('showMidnightAs24', "", false, false),
    __metadata("design:type", String)
], GcDateTimePickerComponent.prototype, "showMidnightAs24", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcDateTimePickerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-datetime-picker',
                    template: ``,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            multi: true,
                            useExisting: forwardRef(() => GcDateTimePickerComponent),
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { selectedValue: [{
                type: Input
            }], maxDate: [{
                type: Input
            }], minDate: [{
                type: Input
            }], type: [{
                type: Input
            }], minuteInterval: [{
                type: Input
            }], secondsInterval: [{
                type: Input
            }], visible: [{
                type: Input
            }], hasSeconds: [{
                type: Input
            }], showMidnightAs24: [{
                type: Input
            }], yearFormat: [{
                type: Input
            }], monthFormat: [{
                type: Input
            }], dayFormat: [{
                type: Input
            }], selectedDateChanged: [{
                type: Output
            }], selectedValueChange: [{
                type: Output
            }] } });

class GcFormPersistenceComponent extends GcComponents {
    constructor(ref) {
        super(ref);
    }
    initGcComponent() {
        var form = this._container.querySelector('form');
        if (form) {
            this._imCtrl = new GC.InputMan.GcFormPersistence(form, this);
            this._imCtrl.persist();
        }
    }
    bindEvent() { }
}
GcFormPersistenceComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcFormPersistenceComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcFormPersistenceComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcFormPersistenceComponent, selector: "gc-form-persistence", inputs: { id: "id", storageMode: "storageMode", saveMode: "saveMode" }, providers: [provideParent(GcFormPersistenceComponent)], usesInheritance: true, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcFormPersistenceComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-form-persistence',
                    template: `<ng-content></ng-content>`,
                    providers: [provideParent(GcFormPersistenceComponent)]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { id: [{
                type: Input
            }], storageMode: [{
                type: Input
            }], saveMode: [{
                type: Input
            }] } });

class GcFunctionKeyInfoComponent {
}
GcFunctionKeyInfoComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcFunctionKeyInfoComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
GcFunctionKeyInfoComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcFunctionKeyInfoComponent, selector: "gc-function-key-info", inputs: { key: "key", description: "description", tipText: "tipText", displayStyle: "displayStyle", imagePosition: "imagePosition" }, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcFunctionKeyInfoComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-function-key-info',
                    template: ``
                }]
        }], propDecorators: { key: [{
                type: Input
            }], description: [{
                type: Input
            }], tipText: [{
                type: Input
            }], displayStyle: [{
                type: Input
            }], imagePosition: [{
                type: Input
            }] } });
class GcFunctionKeyComponent extends GcComponents {
    constructor(ref) {
        super(ref);
        this.onActived = new EventEmitter();
    }
    initGcComponent() {
        if (this.functionKeyComponents && this.functionKeyComponents.length > 0) {
            this.functionKeys = [];
            this.functionKeyComponents.forEach((functionKeyInfo) => {
                this.functionKeys.push({
                    key: functionKeyInfo.key,
                    description: functionKeyInfo.description,
                    tipText: functionKeyInfo.tipText,
                    displayStyle: functionKeyInfo.displayStyle,
                    imagePosition: functionKeyInfo.imagePosition
                });
            });
        }
        var element = document.createElement('div');
        this.createTemplate(element);
        this._imCtrl = new GC.InputMan.GcFunctionKey(element, this);
    }
    bindEvent() {
        if (!this._imCtrl)
            return;
        this._imCtrl.onActived((s, e) => {
            this.onActived.emit(e);
        });
    }
}
GcFunctionKeyComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcFunctionKeyComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcFunctionKeyComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcFunctionKeyComponent, selector: "gc-function-key", inputs: { keyRepeat: "keyRepeat", handleMouse: "handleMouse", showTip: "showTip", combinationKeyDisplayMode: "combinationKeyDisplayMode", functionKeys: "functionKeys", enabled: "enabled", visible: "visible" }, outputs: { onActived: "onActived" }, queries: [{ propertyName: "functionKeyComponents", predicate: GcFunctionKeyInfoComponent }], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
__decorate([
    Property("addFunctionKey", "", true),
    __metadata("design:type", Array)
], GcFunctionKeyComponent.prototype, "functionKeys", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcFunctionKeyComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-function-key',
                    template: ``
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { keyRepeat: [{
                type: Input
            }], handleMouse: [{
                type: Input
            }], showTip: [{
                type: Input
            }], combinationKeyDisplayMode: [{
                type: Input
            }], functionKeys: [{
                type: Input
            }], enabled: [{
                type: Input
            }], visible: [{
                type: Input
            }], functionKeyComponents: [{
                type: ContentChildren,
                args: [GcFunctionKeyInfoComponent]
            }], onActived: [{
                type: Output
            }] } });

class GcIconNotifierComponent extends GcComponents {
    constructor(ref, _parent) {
        super(ref);
        this._parent = _parent;
    }
    ngAfterViewInit() {
        if (!this._parent || typeof this._parent !== 'object' ||
            typeof this._parent.getNestedIMControl() !== 'object') {
            return;
        }
        this._imCtrl = new GC.InputMan.GcIconNotifier(this._parent.getNestedIMControl(), this);
        this.onInitialized.emit(this._imCtrl);
    }
    bindEvent() { }
    initGcComponent() {
    }
    onFail() {
        return this._imCtrl.onFail();
    }
    onSuccess() {
        return this._imCtrl.onSuccess();
    }
    onClear() {
        return this._imCtrl.onClear();
    }
}
GcIconNotifierComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcIconNotifierComponent, deps: [{ token: i0.ElementRef }, { token: GcComponents, optional: true }], target: i0.ɵɵFactoryTarget.Component });
GcIconNotifierComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcIconNotifierComponent, selector: "gc-icon-notifier", inputs: { direction: "direction", failIcon: "failIcon", successIcon: "successIcon", failMessage: "failMessage", successMessage: "successMessage" }, usesInheritance: true, ngImport: i0, template: ``, isInline: true });
__decorate([
    Property('setFailIconSrc'),
    __metadata("design:type", String)
], GcIconNotifierComponent.prototype, "failIcon", void 0);
__decorate([
    Property('setSuccessIconSrc'),
    __metadata("design:type", String)
], GcIconNotifierComponent.prototype, "successIcon", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcIconNotifierComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-icon-notifier',
                    template: ``,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: GcComponents, decorators: [{
                    type: Optional
                }] }]; }, propDecorators: { direction: [{
                type: Input
            }], failIcon: [{
                type: Input
            }], successIcon: [{
                type: Input
            }], failMessage: [{
                type: Input
            }], successMessage: [{
                type: Input
            }] } });

class GcListBoxColumnComponent {
}
GcListBoxColumnComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcListBoxColumnComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
GcListBoxColumnComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcListBoxColumnComponent, selector: "gc-list-box-column", inputs: { name: "name", label: "label", width: "width", isValuePath: "isValuePath", visible: "visible", clickSort: "clickSort", contentAlignment: "contentAlignment", headerAlignment: "headerAlignment", showTip: "showTip" }, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcListBoxColumnComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-list-box-column',
                    template: ``,
                }]
        }], propDecorators: { name: [{
                type: Input
            }], label: [{
                type: Input
            }], width: [{
                type: Input
            }], isValuePath: [{
                type: Input
            }], visible: [{
                type: Input
            }], clickSort: [{
                type: Input
            }], contentAlignment: [{
                type: Input
            }], headerAlignment: [{
                type: Input
            }], showTip: [{
                type: Input
            }] } });
class GcListBoxComponent extends GcComponents {
    constructor(ref) {
        super(ref);
        this.checkedChanged = new EventEmitter();
        this.selectedChanged = new EventEmitter();
        this.focusedChanged = new EventEmitter();
        this.itemClick = new EventEmitter();
        this.loadComplete = new EventEmitter();
        this.itemsChanged = new EventEmitter();
        this.selectedIndexChange = new EventEmitter();
        this.checkedIndexChange = new EventEmitter();
        this.selectedIndicesChange = new EventEmitter();
        this.checkedIndicesChange = new EventEmitter();
    }
    initGcComponent() {
        if (this.columnComponents && this.columnComponents.length > 0) {
            this.columns = [];
            this.columnComponents.forEach((column) => {
                this.columns.push({
                    name: column.name,
                    label: column.label,
                    width: column.width,
                    isValuePath: column.isValuePath,
                    visible: column.visible,
                    clickSort: column.clickSort,
                    contentAlignment: column.contentAlignment,
                    headerAlignment: column.headerAlignment,
                    showTip: column.showTip
                });
            });
        }
        var element = document.createElement('select');
        this.createTemplate(element);
        this._imCtrl = new GC.InputMan.GcListBox(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        this._imCtrl.addEventListener(GC.InputMan.GcListBoxEvent.CheckedChanged, (eventArgs) => {
            this.checkedChanged.emit(eventArgs);
            this.checkedIndexChange.emit(this._imCtrl.getCheckedIndices()[0]);
            this.checkedIndicesChange.emit(this._imCtrl.getCheckedIndices());
        });
        this._imCtrl.addEventListener(GC.InputMan.GcListBoxEvent.SelectedChanged, (eventArgs) => {
            this.selectedChanged.emit(eventArgs);
            this.selectedIndexChange.emit(this._imCtrl.getSelectedIndex());
            this.selectedIndicesChange.emit(this._imCtrl.getSelectedIndices());
        });
        this._imCtrl.addEventListener(GC.InputMan.GcListBoxEvent.FocusedChanged, (eventArgs) => {
            this.focusedChanged.emit(eventArgs);
        });
        this._imCtrl.addEventListener(GC.InputMan.GcListBoxEvent.ItemClick, (sender, eventArgs) => {
            this.itemClick.emit({ sender: sender, eArgs: eventArgs });
        });
        this._imCtrl.addEventListener(GC.InputMan.GcListBoxEvent.LoadComplete, (eventArgs) => {
            this.loadComplete.emit(eventArgs);
        });
        this._imCtrl.addEventListener(GC.InputMan.GcListBoxEvent.ItemsChanged, (eventArgs) => {
            this.itemsChanged.emit(eventArgs);
        });
    }
}
GcListBoxComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcListBoxComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcListBoxComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcListBoxComponent, selector: "gc-list-box", inputs: { items: "items", columns: "columns", virtualMode: "virtualMode", allowResize: "allowResize", selectionMode: "selectionMode", selectedIndex: "selectedIndex", checkedIndex: "checkedIndex", selectedIndices: "selectedIndices", checkedIndices: "checkedIndices", allowColumnResize: "allowColumnResize", overflow: "overflow", width: "width", height: "height", itemHeight: "itemHeight", checkOnClick: "checkOnClick", visibleItems: "visibleItems", visible: "visible", enabled: "enabled", showTip: "showTip", multiColumn: "multiColumn", colHeaderHeight: "colHeaderHeight", showHeader: "showHeader", valueMemberPath: "valueMemberPath", displayMemberPath: "displayMemberPath", showCheckBox: "showCheckBox", itemTemplate: "itemTemplate", headerTemplate: "headerTemplate", footerTemplate: "footerTemplate", emptyTemplate: "emptyTemplate", load: "load", pageSize: "pageSize", generatingItem: "generatingItem", selectTemplate: "selectTemplate", formatItem: "formatItem" }, outputs: { checkedChanged: "checkedChanged", selectedChanged: "selectedChanged", focusedChanged: "focusedChanged", itemClick: "itemClick", loadComplete: "loadComplete", itemsChanged: "itemsChanged", selectedIndexChange: "selectedIndexChange", checkedIndexChange: "checkedIndexChange", selectedIndicesChange: "selectedIndicesChange", checkedIndicesChange: "checkedIndicesChange" }, queries: [{ propertyName: "columnComponents", predicate: GcListBoxColumnComponent }], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
__decorate([
    Property("", "", false, false),
    __metadata("design:type", Number)
], GcListBoxComponent.prototype, "selectedIndex", void 0);
__decorate([
    Property("", "", false, false),
    __metadata("design:type", Number)
], GcListBoxComponent.prototype, "checkedIndex", void 0);
__decorate([
    Property("", "", false, false),
    __metadata("design:type", Array)
], GcListBoxComponent.prototype, "selectedIndices", void 0);
__decorate([
    Property("", "", false, false),
    __metadata("design:type", Array)
], GcListBoxComponent.prototype, "checkedIndices", void 0);
__decorate([
    Property("resizeWidth"),
    __metadata("design:type", Object)
], GcListBoxComponent.prototype, "width", void 0);
__decorate([
    Property("resizeHeight"),
    __metadata("design:type", Number)
], GcListBoxComponent.prototype, "height", void 0);
__decorate([
    Property('setVisibleItemCount'),
    __metadata("design:type", Number)
], GcListBoxComponent.prototype, "visibleItems", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcListBoxComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-list-box',
                    template: ``,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { items: [{
                type: Input
            }], columns: [{
                type: Input
            }], virtualMode: [{
                type: Input
            }], allowResize: [{
                type: Input
            }], selectionMode: [{
                type: Input
            }], selectedIndex: [{
                type: Input
            }], checkedIndex: [{
                type: Input
            }], selectedIndices: [{
                type: Input
            }], checkedIndices: [{
                type: Input
            }], allowColumnResize: [{
                type: Input
            }], overflow: [{
                type: Input
            }], width: [{
                type: Input
            }], height: [{
                type: Input
            }], itemHeight: [{
                type: Input
            }], checkOnClick: [{
                type: Input
            }], visibleItems: [{
                type: Input
            }], visible: [{
                type: Input
            }], enabled: [{
                type: Input
            }], showTip: [{
                type: Input
            }], multiColumn: [{
                type: Input
            }], colHeaderHeight: [{
                type: Input
            }], showHeader: [{
                type: Input
            }], valueMemberPath: [{
                type: Input
            }], displayMemberPath: [{
                type: Input
            }], showCheckBox: [{
                type: Input
            }], itemTemplate: [{
                type: Input
            }], headerTemplate: [{
                type: Input
            }], footerTemplate: [{
                type: Input
            }], emptyTemplate: [{
                type: Input
            }], load: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], generatingItem: [{
                type: Input
            }], selectTemplate: [{
                type: Input
            }], formatItem: [{
                type: Input
            }], checkedChanged: [{
                type: Output
            }], selectedChanged: [{
                type: Output
            }], focusedChanged: [{
                type: Output
            }], itemClick: [{
                type: Output
            }], loadComplete: [{
                type: Output
            }], itemsChanged: [{
                type: Output
            }], selectedIndexChange: [{
                type: Output
            }], checkedIndexChange: [{
                type: Output
            }], selectedIndicesChange: [{
                type: Output
            }], checkedIndicesChange: [{
                type: Output
            }], columnComponents: [{
                type: ContentChildren,
                args: [GcListBoxColumnComponent]
            }] } });

class GcMaskComponent extends GcInputManBaseComponent {
    constructor(ref) {
        super(ref);
        this.onTextChanging = new EventEmitter();
        this.onSpinDown = new EventEmitter();
        this.onSpinUp = new EventEmitter();
        this.onValueChanged = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.valueChange = new EventEmitter();
        this.valueIsFullChange = new EventEmitter();
    }
    writeValue(value) {
        this.value = value;
        if (this._imCtrl) {
            this._imCtrl.value = this.value;
        }
    }
    registerOnChange(onChange) {
        this.onChange = onChange;
    }
    registerOnTouched(onTouched) {
        this.onTouched = onTouched;
    }
    setDisabledState(isDisabled) {
        this._imCtrl.enabled = !isDisabled;
    }
    initGcComponent() {
        var input = document.createElement('input');
        this.createTemplate(input);
        this._imCtrl = new GC.InputMan.GcMask(input, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        super.bindEvent();
        this._imCtrl.onInput((s) => {
            this.valueIsFullChange.emit(s.getValueIsFull());
        });
        this._imCtrl.onTextChanging((s, e) => { this.onTextChanging.emit({ sender: s, eArgs: e }); });
        this._imCtrl.onSpinDown((s) => { this.onSpinDown.emit(s); });
        this._imCtrl.onSpinUp((s) => { this.onSpinUp.emit(s); });
        this._imCtrl.onValueChanged((s) => {
            this.onValueChanged.emit(s);
            this.onChange(s.getValue());
            this.onTouched();
            this.valueChange.emit(s.getValue());
            this.valueIsFullChange.emit(s.getValueIsFull());
        });
    }
}
GcMaskComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcMaskComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcMaskComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcMaskComponent, selector: "gc-mask", inputs: { autoConvert: "autoConvert", value: "value", formatPattern: "formatPattern", promptChar: "promptChar", showLiterals: "showLiterals", tabAction: "tabAction", text: "text", clipContent: "clipContent", allowSpin: "allowSpin", spinWheel: "spinWheel", spinOnKeys: "spinOnKeys", exitOnLastChar: "exitOnLastChar", highlightText: "highlightText", showSpinButton: "showSpinButton", spinButtonPosition: "spinButtonPosition", valueIsFull: "valueIsFull", showClearButton: "showClearButton" }, outputs: { onTextChanging: "onTextChanging", onSpinDown: "onSpinDown", onSpinUp: "onSpinUp", onValueChanged: "onValueChanged", valueChange: "valueChange", valueIsFullChange: "valueIsFullChange" }, providers: [
        provideParent(GcMaskComponent),
        {
            provide: NG_VALUE_ACCESSOR,
            multi: true,
            useExisting: forwardRef(() => GcMaskComponent),
        }
    ], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcMaskComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-mask',
                    template: ``,
                    providers: [
                        provideParent(GcMaskComponent),
                        {
                            provide: NG_VALUE_ACCESSOR,
                            multi: true,
                            useExisting: forwardRef(() => GcMaskComponent),
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { autoConvert: [{
                type: Input
            }], value: [{
                type: Input
            }], formatPattern: [{
                type: Input
            }], promptChar: [{
                type: Input
            }], showLiterals: [{
                type: Input
            }], tabAction: [{
                type: Input
            }], text: [{
                type: Input
            }], clipContent: [{
                type: Input
            }], allowSpin: [{
                type: Input
            }], spinWheel: [{
                type: Input
            }], spinOnKeys: [{
                type: Input
            }], exitOnLastChar: [{
                type: Input
            }], highlightText: [{
                type: Input
            }], showSpinButton: [{
                type: Input
            }], spinButtonPosition: [{
                type: Input
            }], valueIsFull: [{
                type: Input
            }], showClearButton: [{
                type: Input
            }], onTextChanging: [{
                type: Output
            }], onSpinDown: [{
                type: Output
            }], onSpinUp: [{
                type: Output
            }], onValueChanged: [{
                type: Output
            }], valueChange: [{
                type: Output
            }], valueIsFullChange: [{
                type: Output
            }] } });

class GcMultilineTextBoxComponent extends GcInputManBaseComponent {
    constructor(ref) {
        super(ref);
        this.onEditStatusChanged = new EventEmitter();
        this.onInvalidInput = new EventEmitter();
        this.onKeyExit = new EventEmitter();
        this.onTextChanged = new EventEmitter();
        this.onIMEReadingStringOutput = new EventEmitter();
        this.textChange = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.imeReadingStringChange = new EventEmitter();
    }
    writeValue(value) {
        this.text = value;
        if (this._imCtrl) {
            this._imCtrl.text = this.text;
        }
    }
    registerOnChange(onChange) {
        this.onChange = onChange;
    }
    registerOnTouched(onTouched) {
        this.onTouched = onTouched;
    }
    setDisabledState(isDisabled) {
        this._imCtrl.enabled = !isDisabled;
    }
    initGcComponent() {
        var element = document.createElement('textarea');
        this.createTemplate(element);
        this["IMEReadingStringAppend"] = this.imeReadingStringAppend;
        this["IMEReadingStringKanaMode"] = this.imeReadingStringKanaMode;
        this["IMEReadingStringEnableAlphabetReadingMapping"] = this.imeReadingStringEnableAlphabetReadingMapping;
        this._imCtrl = new GC.InputMan.GcMultiLineTextBox(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        super.bindEvent();
        this._imCtrl.onTextChanged((s) => {
            this.onChange(s.getText());
            this.onTouched();
        });
        this._imCtrl.onIMEReadingStringOutput((eventArgs) => {
            this.onIMEReadingStringOutput.emit(eventArgs);
            this.imeReadingStringChange.emit(this._imCtrl.getIMEReadingString());
        });
    }
}
GcMultilineTextBoxComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcMultilineTextBoxComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcMultilineTextBoxComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcMultilineTextBoxComponent, selector: "gc-multiline-textbox", inputs: { countWrappedLine: "countWrappedLine", lengthAsByte: "lengthAsByte", maxLength: "maxLength", maxLineCount: "maxLineCount", imeReadingStringKanaMode: "imeReadingStringKanaMode", scrollBarMode: "scrollBarMode", scrollBars: "scrollBars", wordWrap: "wordWrap", acceptsReturn: "acceptsReturn", acceptsTab: "acceptsTab", imeReadingStringAppend: "imeReadingStringAppend", height: "height", imeReadingStringEnableAlphabetReadingMapping: "imeReadingStringEnableAlphabetReadingMapping", exitOnLastChar: "exitOnLastChar", highlightText: "highlightText", format: "format", autoConvert: "autoConvert", text: "text", lines: "lines", imeReadingString: "imeReadingString", cursorPosition: "cursorPosition" }, outputs: { onEditStatusChanged: "onEditStatusChanged", onInvalidInput: "onInvalidInput", onKeyExit: "onKeyExit", onTextChanged: "onTextChanged", onIMEReadingStringOutput: "onIMEReadingStringOutput", textChange: "textChange", imeReadingStringChange: "imeReadingStringChange" }, providers: [
        provideParent(GcMultilineTextBoxComponent),
        {
            provide: NG_VALUE_ACCESSOR,
            multi: true,
            useExisting: forwardRef(() => GcMultilineTextBoxComponent),
        }
    ], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
__decorate([
    Property("setIMEReadingStringKanaMode"),
    __metadata("design:type", String)
], GcMultilineTextBoxComponent.prototype, "imeReadingStringKanaMode", void 0);
__decorate([
    Property("setIMEReadingStringAppend"),
    __metadata("design:type", Boolean)
], GcMultilineTextBoxComponent.prototype, "imeReadingStringAppend", void 0);
__decorate([
    Property("setIMEReadingStringEnableAlphabetReadingMapping"),
    __metadata("design:type", Boolean)
], GcMultilineTextBoxComponent.prototype, "imeReadingStringEnableAlphabetReadingMapping", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcMultilineTextBoxComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-multiline-textbox',
                    template: ``,
                    providers: [
                        provideParent(GcMultilineTextBoxComponent),
                        {
                            provide: NG_VALUE_ACCESSOR,
                            multi: true,
                            useExisting: forwardRef(() => GcMultilineTextBoxComponent),
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { countWrappedLine: [{
                type: Input
            }], lengthAsByte: [{
                type: Input
            }], maxLength: [{
                type: Input
            }], maxLineCount: [{
                type: Input
            }], imeReadingStringKanaMode: [{
                type: Input
            }], scrollBarMode: [{
                type: Input
            }], scrollBars: [{
                type: Input
            }], wordWrap: [{
                type: Input
            }], acceptsReturn: [{
                type: Input
            }], acceptsTab: [{
                type: Input
            }], imeReadingStringAppend: [{
                type: Input
            }], height: [{
                type: Input
            }], imeReadingStringEnableAlphabetReadingMapping: [{
                type: Input
            }], exitOnLastChar: [{
                type: Input
            }], highlightText: [{
                type: Input
            }], format: [{
                type: Input
            }], autoConvert: [{
                type: Input
            }], text: [{
                type: Input
            }], lines: [{
                type: Input
            }], imeReadingString: [{
                type: Input
            }], cursorPosition: [{
                type: Input
            }], onEditStatusChanged: [{
                type: Output
            }], onInvalidInput: [{
                type: Output
            }], onKeyExit: [{
                type: Output
            }], onTextChanged: [{
                type: Output
            }], onIMEReadingStringOutput: [{
                type: Output
            }], textChange: [{
                type: Output
            }], imeReadingStringChange: [{
                type: Output
            }] } });

class GcNumberComponent extends GcInputManBaseComponent {
    constructor(ref) {
        super(ref);
        this.onSpinDown = new EventEmitter();
        this.onSpinUp = new EventEmitter();
        this.onInvalidRange = new EventEmitter();
        this.onValueChanged = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.valueChange = new EventEmitter();
    }
    writeValue(value) {
        this.value = value;
        if (this._imCtrl) {
            this._imCtrl.value = this.value;
        }
    }
    registerOnChange(onChange) {
        this.onChange = onChange;
    }
    registerOnTouched(onTouched) {
        this.onTouched = onTouched;
    }
    setDisabledState(isDisabled) {
        this._imCtrl.enabled = !isDisabled;
    }
    initGcComponent() {
        var element = document.createElement('input');
        this.createTemplate(element);
        this._imCtrl = new GC.InputMan.GcNumber(element, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        super.bindEvent();
        this._imCtrl.onSpinDown((s) => { this.onSpinDown.emit(s); });
        this._imCtrl.onSpinUp((s) => { this.onSpinUp.emit(s); });
        this._imCtrl.onInvalidRange((s) => { this.onInvalidRange.emit(s); });
        this._imCtrl.onValueChanged((s) => {
            this.onValueChanged.emit(s);
            this.onChange(s.getValue());
            this.onTouched();
            this.valueChange.emit(s.getValue());
        });
    }
    clear() {
        return this._imCtrl.clear();
    }
}
GcNumberComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcNumberComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcNumberComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcNumberComponent, selector: "gc-number", inputs: { value: "value", text: "text", watermarkZeroText: "watermarkZeroText", formatDigit: "formatDigit", displayPositivePrefix: "displayPositivePrefix", displayFormatDigit: "displayFormatDigit", maxValue: "maxValue", minValue: "minValue", positivePrefix: "positivePrefix", positiveSuffix: "positiveSuffix", displayPositiveSuffix: "displayPositiveSuffix", negativePrefix: "negativePrefix", displayNegativePrefix: "displayNegativePrefix", negativeSuffix: "negativeSuffix", displayNegativeSuffix: "displayNegativeSuffix", valueSign: "valueSign", adjustValueOnFocus: "adjustValueOnFocus", allowDeleteToNull: "allowDeleteToNull", clearAction: "clearAction", acceptsDecimal: "acceptsDecimal", currencySymbol: "currencySymbol", decimalPoint: "decimalPoint", maxMinBehavior: "maxMinBehavior", separator: "separator", watermarkDisplayZeroText: "watermarkDisplayZeroText", highlightText: "highlightText", allowSpin: "allowSpin", spinWheel: "spinWheel", spinOnKeys: "spinOnKeys", spinWrap: "spinWrap", showSpinButton: "showSpinButton", spinButtonPosition: "spinButtonPosition", showNumericPad: "showNumericPad", numericPadPosition: "numericPadPosition", showCalculatorAsDropDown: "showCalculatorAsDropDown", showCalculatorAsPopup: "showCalculatorAsPopup", calculatorButtonPosition: "calculatorButtonPosition", dropDownConfig: "dropDownConfig", showClearButton: "showClearButton" }, outputs: { onSpinDown: "onSpinDown", onSpinUp: "onSpinUp", onInvalidRange: "onInvalidRange", onValueChanged: "onValueChanged", valueChange: "valueChange" }, providers: [
        provideParent(GcNumberComponent),
        {
            provide: NG_VALUE_ACCESSOR,
            multi: true,
            useExisting: forwardRef(() => GcNumberComponent),
        }
    ], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcNumberComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-number',
                    template: ``,
                    providers: [
                        provideParent(GcNumberComponent),
                        {
                            provide: NG_VALUE_ACCESSOR,
                            multi: true,
                            useExisting: forwardRef(() => GcNumberComponent),
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { value: [{
                type: Input
            }], text: [{
                type: Input
            }], watermarkZeroText: [{
                type: Input
            }], formatDigit: [{
                type: Input
            }], displayPositivePrefix: [{
                type: Input
            }], displayFormatDigit: [{
                type: Input
            }], maxValue: [{
                type: Input
            }], minValue: [{
                type: Input
            }], positivePrefix: [{
                type: Input
            }], positiveSuffix: [{
                type: Input
            }], displayPositiveSuffix: [{
                type: Input
            }], negativePrefix: [{
                type: Input
            }], displayNegativePrefix: [{
                type: Input
            }], negativeSuffix: [{
                type: Input
            }], displayNegativeSuffix: [{
                type: Input
            }], valueSign: [{
                type: Input
            }], adjustValueOnFocus: [{
                type: Input
            }], allowDeleteToNull: [{
                type: Input
            }], clearAction: [{
                type: Input
            }], acceptsDecimal: [{
                type: Input
            }], currencySymbol: [{
                type: Input
            }], decimalPoint: [{
                type: Input
            }], maxMinBehavior: [{
                type: Input
            }], separator: [{
                type: Input
            }], watermarkDisplayZeroText: [{
                type: Input
            }], highlightText: [{
                type: Input
            }], allowSpin: [{
                type: Input
            }], spinWheel: [{
                type: Input
            }], spinOnKeys: [{
                type: Input
            }], spinWrap: [{
                type: Input
            }], showSpinButton: [{
                type: Input
            }], spinButtonPosition: [{
                type: Input
            }], showNumericPad: [{
                type: Input
            }], numericPadPosition: [{
                type: Input
            }], showCalculatorAsDropDown: [{
                type: Input
            }], showCalculatorAsPopup: [{
                type: Input
            }], calculatorButtonPosition: [{
                type: Input
            }], dropDownConfig: [{
                type: Input
            }], showClearButton: [{
                type: Input
            }], onSpinDown: [{
                type: Output
            }], onSpinUp: [{
                type: Output
            }], onInvalidRange: [{
                type: Output
            }], onValueChanged: [{
                type: Output
            }], valueChange: [{
                type: Output
            }] } });

class GcShortcutInfoComponent {
}
GcShortcutInfoComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcShortcutInfoComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
GcShortcutInfoComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcShortcutInfoComponent, selector: "gc-shortcut-info", inputs: { shortcutKey: "shortcutKey", shift: "shift", ctrl: "ctrl", alt: "alt", target: "target", action: "action", blockMessage: "blockMessage" }, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcShortcutInfoComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-shortcut-info',
                    template: ``
                }]
        }], propDecorators: { shortcutKey: [{
                type: Input
            }], shift: [{
                type: Input
            }], ctrl: [{
                type: Input
            }], alt: [{
                type: Input
            }], target: [{
                type: Input
            }], action: [{
                type: Input
            }], blockMessage: [{
                type: Input
            }] } });
class GcShortcutComponent extends GcComponents {
    constructor(ref) {
        super(ref);
        this.preAction = new EventEmitter();
        this.postAction = new EventEmitter();
    }
    initGcComponent() {
        this._imCtrl = new GC.InputMan.GcShortcut();
        if (this.shortcutInfoList && this.shortcutInfoList.length > 0) {
            this.shortcutInfoList.forEach((info) => {
                let target = this.tryGetTarget(info.target);
                if (target === null)
                    return;
                let args = Object.assign(Object.assign({}, info), { key: info.shortcutKey, target });
                this._imCtrl.add(args);
            });
        }
    }
    tryGetTarget(str) {
        if (str === undefined)
            return window;
        let el = document.querySelector(str);
        if (el === null)
            return null;
        return el[IMCtrl] || el;
    }
    bindEvent() {
        if (!this._imCtrl)
            return;
        this._imCtrl.addEventListener(GC.InputMan.GcShortcutEvent.PreAction, (s, e) => {
            this.preAction.emit(e);
        });
        this._imCtrl.addEventListener(GC.InputMan.GcShortcutEvent.PostAction, (s, e) => {
            this.postAction.emit(e);
        });
    }
}
GcShortcutComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcShortcutComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcShortcutComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcShortcutComponent, selector: "gc-shortcut", inputs: { blockMessage: "blockMessage", triggerAll: "triggerAll" }, outputs: { preAction: "preAction", postAction: "postAction" }, queries: [{ propertyName: "shortcutInfoList", predicate: GcShortcutInfoComponent }], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcShortcutComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-shortcut',
                    template: ``
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { blockMessage: [{
                type: Input
            }], triggerAll: [{
                type: Input
            }], shortcutInfoList: [{
                type: ContentChildren,
                args: [GcShortcutInfoComponent]
            }], preAction: [{
                type: Output
            }], postAction: [{
                type: Output
            }] } });

class GcSoftKeyboardComponent extends GcComponents {
    constructor(ref) {
        super(ref);
        this.onOpen = new EventEmitter();
        this.onClose = new EventEmitter();
        this.onKeyPress = new EventEmitter();
    }
    initGcComponent() {
        var element = document.createElement('div');
        this.createTemplate(element);
        this._imCtrl = new GC.InputMan.GcSoftKeyboard(element, this);
        this.setTarget(this.target);
        this.setOpened(this.opened);
    }
    bindEvent() {
        if (!this._imCtrl)
            return;
        this._imCtrl.addEventListener(GC.InputMan.GcSoftKeyboardEvent.KeyPress, (s, e) => {
            this.onKeyPress.emit(e);
        });
        this._imCtrl.addEventListener(GC.InputMan.GcSoftKeyboardEvent.Open, (s) => {
            this.onOpen.emit(s);
        });
        this._imCtrl.addEventListener(GC.InputMan.GcSoftKeyboardEvent.Close, (s) => {
            this.onClose.emit(s);
        });
    }
    setValueToIMControl(key, value) {
        if (key === 'opened') {
            this.setOpened(value);
        }
        else if (key === 'target') {
            this.setTarget(value);
        }
        else {
            super.setValueToIMControl(key, value);
        }
    }
    setOpened(opened) {
        if (opened === true) {
            this._imCtrl.open();
        }
        else if (opened === false) {
            this._imCtrl.close();
        }
    }
    setTarget(str) {
        let target = this.tryGetTarget(str);
        if (target) {
            this._imCtrl.target = target;
        }
    }
    tryGetTarget(str) {
        try {
            let target = document.querySelector(str);
            return target;
        }
        catch (_a) { }
        return null;
    }
}
GcSoftKeyboardComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcSoftKeyboardComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcSoftKeyboardComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcSoftKeyboardComponent, selector: "gc-soft-keyboard", inputs: { opened: "opened", randomDisplay: "randomDisplay", hideButtonWhenMouseOn: "hideButtonWhenMouseOn", displayType: "displayType", showSecurityOptions: "showSecurityOptions", securityLevel: "securityLevel", qwertyLayout: "qwertyLayout", showCapitalLetters: "showCapitalLetters", target: "target", enabled: "enabled" }, outputs: { onOpen: "onOpen", onClose: "onClose", onKeyPress: "onKeyPress" }, usesInheritance: true, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcSoftKeyboardComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-soft-keyboard',
                    template: ``
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { opened: [{
                type: Input
            }], randomDisplay: [{
                type: Input
            }], hideButtonWhenMouseOn: [{
                type: Input
            }], displayType: [{
                type: Input
            }], showSecurityOptions: [{
                type: Input
            }], securityLevel: [{
                type: Input
            }], qwertyLayout: [{
                type: Input
            }], showCapitalLetters: [{
                type: Input
            }], target: [{
                type: Input
            }], enabled: [{
                type: Input
            }], onOpen: [{
                type: Output
            }], onClose: [{
                type: Output
            }], onKeyPress: [{
                type: Output
            }] } });

class GcTextBoxComponent extends GcInputManBaseComponent {
    constructor(ref) {
        super(ref);
        this.onIMEReadingStringOutput = new EventEmitter();
        // For V2.1 Compatibility, we have to keep this property or event
        this.imeReadingStringChange = new EventEmitter();
    }
    writeValue(value) {
        this.text = value;
        if (this._imCtrl) {
            this._imCtrl.text = this.text;
        }
    }
    registerOnChange(onChange) {
        this.onChange = onChange;
    }
    registerOnTouched(onTouched) {
        this.onTouched = onTouched;
    }
    setDisabledState(isDisabled) {
        this._imCtrl.enabled = !isDisabled;
    }
    initGcComponent() {
        var input = document.createElement("input");
        this.createTemplate(input);
        this["IMEReadingStringAppend"] = this.imeReadingStringAppend;
        this["IMEReadingStringKanaMode"] = this.imeReadingStringKanaMode;
        this["IMEReadingStringEnableAlphabetReadingMapping"] = this.imeReadingStringEnableAlphabetReadingMapping;
        this._imCtrl = new GC.InputMan.GcTextBox(input, this);
    }
    bindEvent() {
        if (!this._imCtrl) {
            return;
        }
        super.bindEvent();
        this._imCtrl.onTextChanged((s) => {
            this.onTouched();
            this.onChange(s.getText());
        });
        this._imCtrl.onIMEReadingStringOutput((s, e) => {
            this.onIMEReadingStringOutput.emit({ sender: s, eArgs: e });
            this.imeReadingStringChange.emit(s.getIMEReadingString());
        });
    }
}
GcTextBoxComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcTextBoxComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
GcTextBoxComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcTextBoxComponent, selector: "gc-text-box", inputs: { autoConvert: "autoConvert", ellipsisString: "ellipsisString", ellipsis: "ellipsis", format: "format", lengthAsByte: "lengthAsByte", maxLength: "maxLength", passwordChar: "passwordChar", text: "text", useSystemPasswordChar: "useSystemPasswordChar", imeReadingStringAppend: "imeReadingStringAppend", imeReadingStringKanaMode: "imeReadingStringKanaMode", imeReadingStringEnableAlphabetReadingMapping: "imeReadingStringEnableAlphabetReadingMapping", exitOnLastChar: "exitOnLastChar", highlightText: "highlightText", imeReadingString: "imeReadingString", showClearButton: "showClearButton", passwordRevelationMode: "passwordRevelationMode" }, outputs: { onIMEReadingStringOutput: "onIMEReadingStringOutput", imeReadingStringChange: "imeReadingStringChange" }, providers: [
        provideParent(GcTextBoxComponent),
        {
            provide: NG_VALUE_ACCESSOR,
            multi: true,
            useExisting: forwardRef(() => GcTextBoxComponent),
        }
    ], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
__decorate([
    Property("setIMEReadingStringAppend"),
    __metadata("design:type", Boolean)
], GcTextBoxComponent.prototype, "imeReadingStringAppend", void 0);
__decorate([
    Property("setIMEReadingStringKanaMode"),
    __metadata("design:type", String)
], GcTextBoxComponent.prototype, "imeReadingStringKanaMode", void 0);
__decorate([
    Property("setIMEReadingStringEnableAlphabetReadingMapping"),
    __metadata("design:type", Boolean)
], GcTextBoxComponent.prototype, "imeReadingStringEnableAlphabetReadingMapping", void 0);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcTextBoxComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-text-box',
                    template: ``,
                    providers: [
                        provideParent(GcTextBoxComponent),
                        {
                            provide: NG_VALUE_ACCESSOR,
                            multi: true,
                            useExisting: forwardRef(() => GcTextBoxComponent),
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { autoConvert: [{
                type: Input
            }], ellipsisString: [{
                type: Input
            }], ellipsis: [{
                type: Input
            }], format: [{
                type: Input
            }], lengthAsByte: [{
                type: Input
            }], maxLength: [{
                type: Input
            }], passwordChar: [{
                type: Input
            }], text: [{
                type: Input
            }], useSystemPasswordChar: [{
                type: Input
            }], imeReadingStringAppend: [{
                type: Input
            }], imeReadingStringKanaMode: [{
                type: Input
            }], imeReadingStringEnableAlphabetReadingMapping: [{
                type: Input
            }], exitOnLastChar: [{
                type: Input
            }], highlightText: [{
                type: Input
            }], imeReadingString: [{
                type: Input
            }], showClearButton: [{
                type: Input
            }], passwordRevelationMode: [{
                type: Input
            }], onIMEReadingStringOutput: [{
                type: Output
            }], imeReadingStringChange: [{
                type: Output
            }] } });

class GcTipNotifierComponent extends GcComponents {
    constructor(ref, _parent) {
        super(ref);
        this._parent = _parent;
    }
    ngAfterViewInit() {
        if (!this._parent || typeof this._parent !== 'object' ||
            typeof this._parent.getNestedIMControl() !== 'object') {
            return;
        }
        this._imCtrl = new GC.InputMan.GcTipNotifier(this._parent.getNestedIMControl(), this);
        this.onInitialized.emit(this._imCtrl);
    }
    bindEvent() { }
    initGcComponent() {
    }
    onFail() {
        return this._imCtrl.onFail();
    }
    onSuccess() {
        return this._imCtrl.onSuccess();
    }
    onClear() {
        return this._imCtrl.onClear();
    }
}
GcTipNotifierComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcTipNotifierComponent, deps: [{ token: i0.ElementRef }, { token: GcComponents, optional: true }], target: i0.ɵɵFactoryTarget.Component });
GcTipNotifierComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.17", type: GcTipNotifierComponent, selector: "gc-tip-notifier", inputs: { direction: "direction", position: "position", directionPriority: "directionPriority", template: "template", failMessage: "failMessage", successMessage: "successMessage", tipState: "tipState" }, usesInheritance: true, ngImport: i0, template: ``, isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: GcTipNotifierComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'gc-tip-notifier',
                    template: ``,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: GcComponents, decorators: [{
                    type: Optional
                }] }]; }, propDecorators: { direction: [{
                type: Input
            }], position: [{
                type: Input
            }], directionPriority: [{
                type: Input
            }], template: [{
                type: Input
            }], failMessage: [{
                type: Input
            }], successMessage: [{
                type: Input
            }], tipState: [{
                type: Input
            }] } });

/*Import from angular */
/**
 *  Declare & add export modules
 */
class InputManModule {
}
InputManModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: InputManModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
InputManModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: InputManModule, declarations: [GcMaskComponent,
        GcTextBoxComponent,
        GcCalendarComponent,
        GcNumberComponent,
        GcDateTimeComponent,
        GcListBoxComponent,
        GcComboBoxComponent,
        GcDateTimePickerComponent,
        GcTipNotifierComponent,
        GcIconNotifierComponent,
        GcMultilineTextBoxComponent,
        GcComboBoxColumnComponent,
        GcListBoxColumnComponent,
        GcFormPersistenceComponent,
        GcCalculatorComponent,
        GcFunctionKeyComponent,
        GcFunctionKeyInfoComponent,
        GcShortcutComponent,
        GcShortcutInfoComponent,
        GcSoftKeyboardComponent], imports: [CommonModule,
        FormsModule], exports: [GcMaskComponent,
        GcTextBoxComponent,
        GcCalendarComponent,
        GcNumberComponent,
        GcDateTimeComponent,
        GcListBoxComponent,
        GcComboBoxComponent,
        GcDateTimePickerComponent,
        GcTipNotifierComponent,
        GcIconNotifierComponent,
        GcMultilineTextBoxComponent,
        GcComboBoxColumnComponent,
        GcListBoxColumnComponent,
        GcFormPersistenceComponent,
        GcCalculatorComponent,
        GcFunctionKeyComponent,
        GcFunctionKeyInfoComponent,
        GcShortcutComponent,
        GcShortcutInfoComponent,
        GcSoftKeyboardComponent] });
InputManModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: InputManModule, imports: [[
            CommonModule,
            FormsModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.17", ngImport: i0, type: InputManModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule
                    ],
                    declarations: [
                        GcMaskComponent,
                        GcTextBoxComponent,
                        GcCalendarComponent,
                        GcNumberComponent,
                        GcDateTimeComponent,
                        GcListBoxComponent,
                        GcComboBoxComponent,
                        GcDateTimePickerComponent,
                        GcTipNotifierComponent,
                        GcIconNotifierComponent,
                        GcMultilineTextBoxComponent,
                        GcComboBoxColumnComponent,
                        GcListBoxColumnComponent,
                        GcFormPersistenceComponent,
                        GcCalculatorComponent,
                        GcFunctionKeyComponent,
                        GcFunctionKeyInfoComponent,
                        GcShortcutComponent,
                        GcShortcutInfoComponent,
                        GcSoftKeyboardComponent,
                    ],
                    exports: [
                        GcMaskComponent,
                        GcTextBoxComponent,
                        GcCalendarComponent,
                        GcNumberComponent,
                        GcDateTimeComponent,
                        GcListBoxComponent,
                        GcComboBoxComponent,
                        GcDateTimePickerComponent,
                        GcTipNotifierComponent,
                        GcIconNotifierComponent,
                        GcMultilineTextBoxComponent,
                        GcComboBoxColumnComponent,
                        GcListBoxColumnComponent,
                        GcFormPersistenceComponent,
                        GcCalculatorComponent,
                        GcFunctionKeyComponent,
                        GcFunctionKeyInfoComponent,
                        GcShortcutComponent,
                        GcShortcutInfoComponent,
                        GcSoftKeyboardComponent
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { GcCalculatorComponent, GcCalendarComponent, GcComboBoxColumnComponent, GcComboBoxComponent, GcDateTimeComponent, GcDateTimePickerComponent, GcFormPersistenceComponent, GcFunctionKeyComponent, GcFunctionKeyInfoComponent, GcIconNotifierComponent, GcListBoxColumnComponent, GcListBoxComponent, GcMaskComponent, GcMultilineTextBoxComponent, GcNumberComponent, GcShortcutComponent, GcShortcutInfoComponent, GcSoftKeyboardComponent, GcTextBoxComponent, GcTipNotifierComponent, InputManModule };
//# sourceMappingURL=grapecity-inputman.angular.js.map
